Crate typst_html

Crate typst_html 

Typst’s HTML exporter.

Modules

attr
property
Typed CSS properties.
tag
Predefined constants for HTML tags.

Structs

FrameElem
An element that lays out its content as an inline SVG.
HtmlAttr
An attribute of an HTML element.
HtmlAttrs
Attributes of an HTML element.
HtmlDocument
An HTML document.
HtmlElem
An HTML element that can contain Typst content.
HtmlElement
An HTML element.
HtmlFrame
Layouted content that will be embedded into HTML as an SVG.
HtmlIntrospector
An introspector implementation for HTML documents.
HtmlOptions
Settings for HTML export.
HtmlTag
The tag of an HTML element.

Enums

HtmlNode
A child of an HTML element.

Traits

HtmlSliceExt
An extension trait for [HtmlNode].

Functions

create_link_anchors
Attaches IDs to nodes produced by link targets to make them linkable.
html
Encodes an HTML document into a string.
html_document
Produce an HTML document from content.
html_document_for_bundle
Produce an HTML document from content, as part of a bundle compilation process.
html_in_bundle
Encodes an HTML root element into a string as part of a bundle.
module
Creates the module with all HTML definitions.
register
Registers show rules for the HTML target.