pub enum Display {
Show 28 variants
Block,
Inline,
RunIn,
Flow,
FlowRoot,
Table,
Flex,
Grid,
Ruby,
ListItem,
TableRowGroup,
TableHeaderGroup,
TableFooterGroup,
TableRow,
TableCell,
TableColumnGroup,
TableColumn,
TableCaption,
RubyBase,
RubyText,
Contents,
None,
InlineBlock,
InlineTable,
InlineFlex,
InlineGrid,
InlineMath,
BlockMath,
}Expand description
A value for the CSS display property.
https://www.w3.org/TR/css-display-3/#propdef-display https://www.w3.org/TR/mathml-core/#new-display-math-value
Variants
Block
Inline
RunIn
Flow
FlowRoot
Table
Flex
Grid
Ruby
ListItem
TableRowGroup
TableHeaderGroup
TableRow
TableCell
TableColumnGroup
TableColumn
TableCaption
RubyBase
RubyText
Contents
None
InlineBlock
InlineTable
InlineFlex
InlineGrid
InlineMath
BlockMath
Implementations
Sourceimpl Display
impl Display
Sourcepub fn default_for(tag: HtmlTag) -> Option<Self>
pub fn default_for(tag: HtmlTag) -> Option<Self>
Returns the default value for the given tag as defined by the user agent styles in  15 of the HTML spec.
Sourcepub fn is_tabular(self) -> bool
pub fn is_tabular(self) -> bool
Whether this is any of the table(-.*)? display modes.