Module tag

Module tag 

Predefined constants for HTML tags.

Modules

mathml
Elements in the MathML namespace.

Constants

a
abbr
address
area
article
aside
audio
b
base
bdi
bdo
blockquote
body
br
button
canvas
caption
cite
code
col
colgroup
data
datalist
dd
del
details
dfn
dialog
div
dl
dt
em
embed
fieldset
figcaption
figure
footer
form
h1
h2
h3
h4
h5
h6
head
header
hgroup
hr
html
i
iframe
img
input
ins
kbd
label
legend
li
link
main
map
mark
menu
meta
meter
nav
noscript
object
ol
optgroup
option
output
p
picture
pre
progress
q
rp
rt
ruby
s
samp
script
search
section
select
slot
small
source
span
strong
style
sub
summary
sup
table
tbody
td
template
textarea
tfoot
th
thead
time
title
tr
track
u
ul
var
video
wbr

Functions

is_embedded_content
Whether an element is considered embedded content.
is_escapable_raw
Whether this is a tag containing escapable raw text.
is_flow_content
Wether an element is considered flow content.
is_foreign
Whether this is a foreign tag whose associated element is from another namespace.
is_foreign_self_closing
Whether this is a foreign element whose tag is self-closing.
is_heading_content
Whether an element is considered heading content.
is_interactive_content
Whether an element is considered interactive content.
is_metadata_content
Whether an element is considered metadata content.
is_palpable_content
Whether an element is considered palpable content.
is_phrasing_content
Whether an element is considered phrasing content.
is_raw
Whether this is a tag containing raw text.
is_replaced
Whether the element is considered a “replaced element”.
is_script_supporting_element
Whether an element is considered a script-supporting element.
is_sectioning_content
Whether an element is considered sectioning content.
is_void
Whether this is a void tag whose associated element may not have children.
is_whitespace_collapsing
Whether HTML whitespace next to an element with this tag will be collapsed (assuming normal user agent styles).
should_group_into_pars
Whether we group this kind of HTML element into paragraphs if paragraphs are forced in some way (either through being top-level or due to being in the same flow as a Typst-native block element or parbreak). When using solely the low-level HTML API, no paragraphs are ever forced.