Typst’s HTML exporter.
Modules
Structs
- Frame
Elem - An element that lays out its content as an inline SVG.
- Html
Attr - An attribute of an HTML element.
- Html
Attrs - Attributes of an HTML element.
- Html
Document - An HTML document.
- Html
Elem - An HTML element that can contain Typst content.
- Html
Element - An HTML element.
- Html
Frame - Layouted content that will be embedded into HTML as an SVG.
- Html
Introspector - An introspector implementation for HTML documents.
- Html
Options - Settings for HTML export.
- HtmlTag
- The tag of an HTML element.
Enums
- Html
Node - A child of an HTML element.
Traits
- Html
Slice Ext - An extension trait for
[HtmlNode].
Functions
- create_
link_ anchors - Attaches IDs to nodes produced by link targets to make them linkable.
- html
- Encodes an HTML document into a string.
- html_
document - Produce an HTML document from content.
- html_
document_ for_ bundle - Produce an HTML document from content, as part of a bundle compilation process.
- html_
in_ bundle - Encodes an HTML root element into a string as part of a bundle.
- module
- Creates the module with all HTML definitions.
- register
- Registers show rules for the HTML target.