pub fn html_in_bundle(
root: &HtmlElement,
options: &HtmlOptions,
link_resolver: Tracked<'_, LateLinkResolver<'_>>,
) -> SourceResult<String>Expand description
Encodes an HTML root element into a string as part of a bundle.
See export_html in typst-bundle for more details on why this takes the
root element instead of the document.