Predefined constants for HTML tags.
Modules
- mathml
- Elements in the MathML namespace.
Constants
- a
- abbr
- address
- area
- article
- aside
- audio
- b
- base
- bdi
- bdo
- blockquote
- body
- br
- button
- canvas
- caption
- cite
- code
- col
- colgroup
- data
- datalist
- dd
- del
- details
- dfn
- dialog
- div
- dl
- dt
- em
- embed
- fieldset
- figcaption
- figure
- footer
- form
- h1
- h2
- h3
- h4
- h5
- h6
- head
- header
- hgroup
- hr
- html
- i
- iframe
- img
- input
- ins
- kbd
- label
- legend
- li
- link
- main
- map
- mark
- menu
- meta
- meter
- nav
- noscript
- object
- ol
- optgroup
- option
- output
- p
- picture
- pre
- progress
- q
- rp
- rt
- ruby
- s
- samp
- script
- search
- section
- select
- slot
- small
- source
- span
- strong
- style
- sub
- summary
- sup
- table
- tbody
- td
- template
- textarea
- tfoot
- th
- thead
- time
- title
- tr
- track
- u
- ul
- var
- video
- wbr
Functions
- is_
embedded_ content - Whether an element is considered embedded content.
- is_
escapable_ raw - Whether this is a tag containing escapable raw text.
- is_
flow_ content - Wether an element is considered flow content.
- is_
foreign - Whether this is a foreign tag whose associated element is from another namespace.
- is_
foreign_ self_ closing - Whether this is a foreign element whose tag is self-closing.
- is_
heading_ content - Whether an element is considered heading content.
- is_
interactive_ content - Whether an element is considered interactive content.
- is_
metadata_ content - Whether an element is considered metadata content.
- is_
palpable_ content - Whether an element is considered palpable content.
- is_
phrasing_ content - Whether an element is considered phrasing content.
- is_raw
- Whether this is a tag containing raw text.
- is_
replaced - Whether the element is considered a “replaced element”.
- is_
script_ supporting_ element - Whether an element is considered a script-supporting element.
- is_
sectioning_ content - Whether an element is considered sectioning content.
- is_void
- Whether this is a void tag whose associated element may not have children.
- is_
whitespace_ collapsing - Whether HTML whitespace next to an element with this tag will be collapsed (assuming normal user agent styles).
- should_
group_ into_ pars - Whether we group this kind of HTML element into paragraphs if paragraphs
are forced in some way (either through being top-level or due to being in
the same flow as a Typst-native
blockelement orparbreak). When using solely the low-level HTML API, no paragraphs are ever forced.